@@ -44,7 +44,7 @@ class AsyncioEventLoop(BaseEventLoop, asyncio.Protocol,
 
     def connection_lost(self, exc):
         """Used to signal `asyncio.Protocol` of a lost connection."""
-        self._on_error(exc.message)
+        self._on_error(exc.message if exc else 'EOF')
 
     def data_received(self, data):
         """Used to signal `asyncio.Protocol` of incoming data."""
@@ -53,9 +53,9 @@ class AsyncioEventLoop(BaseEventLoop, asyncio.Protocol,
             return
         self._queued_data.append(data)
 
-    def pipe_connection_lost(self, exc):
+    def pipe_connection_lost(self, fd, exc):
         """Used to signal `asyncio.SubprocessProtocol` of a lost connection."""
-        self._on_error(exc.message)
+        self._on_error(exc.message if exc else 'EOF')
 
     def pipe_data_received(self, fd, data):
         """Used to signal `asyncio.SubprocessProtocol` of incoming data."""
